# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "Button widget"

import gobject

from widget import *
from container import Container
from box import HBox
from label import Label
from image import Image

class Button(Container):
    """ 
    A button widget features icon and label, signals for press and release.
    
    """
    
    __gsignals__ = {
        'clicked': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, 
                    (gobject.TYPE_PYOBJECT,))
    }
        
    def __init__(self, icon=None, label=None):
        """ Initialize button widget """
        
        super(Button, self).__init__()
        
        self.icon = icon
        self.label = label
        
        self.set_reactive(True) 
        self.connect('motion-event', self.on_motion_event) 
        self.connect('leave-event', self.on_leave_event) 
        self.connect('button-press-event', self.on_press_event) 
        self.connect('button-release-event', self.on_release_event)
        
        self._init_elements()
        
        self._update_style(self.style)
    
    def _init_elements(self):
        """ Initializes graphical elements """
        
        self._background_image = Image()
        self.add(self._background_image)
        
        self._hbox = HBox()
        self.add(self._hbox)
        self._update_layout()
        
        if self.icon:
            self._icon = Image(self.icon)
            self._icon.size_ratio = 1.0
            self._hbox.pack(self._icon)
        if self.label:
            self._label = Label(self.label)
            self._hbox.pack(self._label)
        
    def _update_style(self, props=None):
        """ Updates style """
        
        super(Button, self)._update_style(props)
        
        for key, value in props:
            if key == 'background-image':
                self.background_image = value
                self._background_image.hide()
                self._background_image.set_source(self.background_image)
                self._background_image._update_layout()
                self._background_image.show()
                
        
    def _update_layout(self):
        """ Updates layout """
        
        super(Button, self)._update_layout()
                
        self._background_image._update_layout()
        self._hbox._update_layout()

    def on_motion_event(self, widget, event):
        """ Cursor motion over widget """
        
        if not self.state == STATE_SELECTED:
            self.state = STATE_HIGHLIGHT
        
    def on_leave_event(self, widget, event):
        """ Cursor leave from widget """
        
        self.state = STATE_NORMAL
        
    def on_press_event(self, widget, event):
        
        self.state = STATE_SELECTED
        self.emit("clicked", self)
        
    def on_release_event(self, widget, event):
        
        self.state = STATE_HIGHLIGHT
        
        
        
        
